@@ -11,7 +11,7 @@ use HTTP::Request();
 use HTTP::Response();
 use POSIX();
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 sub _CHUNK_SIZE                { return 4096 }
 sub _FILE_READ_SIZE            { return 8192 }
@@ -235,6 +235,10 @@ sub _process_icap_headers {
     if ( $icap_headers =~ /\r?\nISTag:[ ]*$quoted_string(?:\r?\n|$)/smx ) {
         $self->{_is_tag} = ($1);
     }
+    elsif ( $icap_headers =~ /\r?\nISTag:[ ]*(\S+)(?:\r?\n|$)/smx )
+    {    # This violates RFC but is necessary to get the c-icap project to work
+        $self->{_is_tag} = ($1);
+    }
     if ( $icap_method eq 'OPTIONS' ) {
         delete $self->{_options};
         if ( $icap_headers =~ /\r?\nMethods:[ ]*(.*?)(?:\r?\n|$)/smx ) {
@@ -725,7 +729,7 @@ Net::ICAP::Client - A client implementation of the ICAP (RFC 3507) protocol
 
 =head1 VERSION
 
-Version 0.04
+Version 0.05
 
 =head1 SYNOPSIS
 
